==> sbol2-1.0b7.tar.gz: sbol2-1.0b7/sbol2/__init__.py <==
__version__ = '1.0b7'

# Anything imported here is part of the public API. Limit what gets
# imported to only those things that are actually needed.
#
# We should be using `__all__` for the list of exported items for this
# module, but the list of items in `constants.py` is extensive. So
# instead of `__all__`, we will try to be careful about what gets
# imported into this file. In the absence of __all__, all imported
# symbols are also exported.
from .attachment import Attachment
from .collection import Collection
from .combinatorialderivation import CombinatorialDerivation
from .component import Component
from .component import FunctionalComponent
from .componentdefinition import ComponentDefinition
from .config import Config, ConfigOptions
from .config import getHomespace, hasHomespace, setHomespace
from .constants import *
from .dbtl import Design
from .document import Document, IGEM_STANDARD_ASSEMBLY
from .experiment import Experiment, ExperimentalData
from .identified import Identified
from .implementation import Implementation
from .interaction import Interaction
from .location import Location, Range, Cut, GenericLocation
from .measurement import Measurement
from .module import Module
from .moduledefinition import ModuleDefinition
from .object import SBOLObject
from .participation import Participation
from .partshop import PartShop
from .property import DateTimeProperty, FloatProperty, IntProperty
from .property import LiteralProperty, OwnedObject
from .property import ReferencedObject, TextProperty
from .property import URIProperty
from .provo import Activity
from .provo import Agent
from .provo import Association
from .provo import Plan
from .provo import Usage
from .sbolerror import SBOLError, SBOLErrorCode
from .sequence import Sequence
from .sequenceannotation import SequenceAnnotation
from .toplevel import TopLevel
from .validation import is_alphanumeric_or_underscore
from .validation import is_not_alphanumeric_or_underscore
from .versionproperty import VersionProperty

==> sbol2-1.4.tar.gz: sbol2-1.4/sbol2/__init__.py <==
__version__ = '1.4'

# Anything imported here is part of the public API. Limit what gets
# imported to only those things that are actually needed.
#
# We should be using `__all__` for the list of exported items for this
# module, but the list of items in `constants.py` is extensive. So
# instead of `__all__`, we will try to be careful about what gets
# imported into this file. In the absence of __all__, all imported
# symbols are also exported.
from .attachment import Attachment
from .collection import Collection
from .combinatorialderivation import CombinatorialDerivation, VariableComponent
from .component import Component
from .component import FunctionalComponent
from .componentdefinition import ComponentDefinition
from .config import Config, ConfigOptions
from .config import getHomespace, hasHomespace, setHomespace
from .constants import *
from .dbtl import Design
from .document import Document, IGEM_STANDARD_ASSEMBLY
from .experiment import Experiment, ExperimentalData
from .identified import Identified
from .implementation import Implementation
from .interaction import Interaction
from .location import Location, Range, Cut, GenericLocation
from .measurement import Measurement
from .module import Module
from .moduledefinition import ModuleDefinition
from .object import SBOLObject
from .participation import Participation
from .searchquery import SearchQuery
from .partshop import PartShop
from .property import DateTimeProperty, FloatProperty, IntProperty
from .property import LiteralProperty, OwnedObject
from .property import ReferencedObject, TextProperty
from .property import URIProperty
from .provo import Activity
from .provo import Agent
from .provo import Association
from .provo import Plan
from .provo import Usage
from .sbolerror import SBOLError, SBOLErrorCode
from .sequence import Sequence
from .sequenceannotation import SequenceAnnotation
from .toplevel import TopLevel
from .validation import is_alphanumeric_or_underscore
from .validation import is_not_alphanumeric_or_underscore
from .versionproperty import VersionProperty
